@@ -819,6 +819,7 @@ class tx_em_Install {
 		$content = '';
 
 		// Updating tables and fields?
+		$showUpdateStatements = TRUE;
 		if (is_array($extInfo['files']) && in_array('ext_tables.sql', $extInfo['files'])) {
 			$path = tx_em_Tools::getExtPath($extKey, $extInfo['type']);
 			$fileContent = t3lib_div::getUrl($path . 'ext_tables.sql');
@@ -838,12 +839,31 @@ class tx_em_Install {
 					$this->install->performUpdateQueries($update_statements['change'], $this->install->INSTALL['database_update']);
 					$this->install->performUpdateQueries($update_statements['create_table'], $this->install->INSTALL['database_update']);
 				} else {
-					$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
-						$update_statements['add'], $GLOBALS['LANG']->getLL('checkDBupdates_add_fields'));
-					$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
-						$update_statements['change'], $GLOBALS['LANG']->getLL('checkDBupdates_changing_fields'), 1, 0, $update_statements['change_currentValue']);
-					$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
-						$update_statements['create_table'], $GLOBALS['LANG']->getLL('checkDBupdates_add_tables'));
+					if (is_array($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['typo3/mod/tools/em/index.php']['checkDBupdates'])) {
+						foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['typo3/mod/tools/em/index.php']['checkDBupdates'] as $classData) {
+							$hookObject = t3lib_div::getUserObj($classData);
+
+							if (!($hookObject instanceof tx_em_Index_CheckDatabaseUpdatesHook)) {
+								throw new UnexpectedValueException('$hookObject must implement interface em_index_checkDatabaseUpdatesHook', 1288418476);
+							}
+
+							/* @var $hookObject tx_em_Index_CheckDatabaseUpdatesHook */
+							$preprocessContent = $hookObject->preProcessDatabaseUpdates($extKey, $extInfo, $diff, $this->install, $this);
+							if ($preprocessContent) {
+								$content .= $preprocessContent;
+								$showUpdateStatements = FALSE;
+								break;
+							}
+						}
+					}
+					if ($showUpdateStatements) {
+						$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
+							$update_statements['add'], $GLOBALS['LANG']->getLL('checkDBupdates_add_fields'));
+						$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
+							$update_statements['change'], $GLOBALS['LANG']->getLL('checkDBupdates_changing_fields'), 1, 0, $update_statements['change_currentValue']);
+						$content .= $this->install->generateUpdateDatabaseForm_checkboxes(
+							$update_statements['create_table'], $GLOBALS['LANG']->getLL('checkDBupdates_add_tables'));
+					}
 				}
 			}
 		}
@@ -1432,14 +1452,13 @@ class tx_em_Install {
 
 		if ($updates || $configForm) {
 			if ($configForm) {
-				$updates = $configForm;
+				$updates =  $formWrap[0] . $configForm . $formWrap[1];
 			} else {
 				$updates = $formWrap[0] . $updates . $addFields . '
 					<br /><input type="submit" name="write" id="update-submit-' . $extKey . '" value="' . $GLOBALS['LANG']->getLL('updatesForm_make_updates') . '" />
 				' . $formWrap[1];
 			}
 		}
-
 		return $updates;
 	}
 
@@ -1581,4 +1600,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['typo3/sysext/em/classes/install/class.tx_em_install.php']);
 }
 
-?>
\ No newline at end of file
+?>
